Reads `SampleA*.fastq.gz` generated by:

```bash
art_illumina -f 20 -l 150 -m 170 -s 50 -o SampleA_ -p -na -ss MSv3 -i SampleA.fasta
```

Reads `SampleA-snpeff*.fastq.gz` generated by:

```bash
art_illumina -f 20 -l 150 -m 170 -s 50 -o SampleA-snpeff_ -p -na -ss MSv3 -i SampleA-snpeff.fasta
```
